package com.diagbot.model.ai.process;

import com.alibaba.fastjson.JSONObject;
import com.diagbot.biz.push.entity.Item;
import com.diagbot.model.ai.model.EntityEnum;
import com.diagbot.model.ai.model.Lemma;
import com.diagbot.model.entity.BodyPart;
import com.diagbot.model.entity.Pacs;
import com.diagbot.model.label.PacsLabel;
import com.diagbot.util.ListUtil;
import com.google.common.collect.Lists;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

public class EntityProcessPacs extends EntityProcess {

    public void extractEntity(JSONObject aiOut, PacsLabel pacsLabel) {
        // 获取描述和部位的关系
        Map<String, List<BodyPart>> bodyMap = new LinkedHashMap<>();
        List<Lemma> pacsLemmas = createEntityTree(aiOut, EntityEnum.AUXILIARY_DESCRIPT.toString());
        for (Lemma lemma : pacsLemmas) {
            List<BodyPart> bodyPartList = new ArrayList<>();
            if (lemma.isHaveChildren()) {
                for (Lemma relationLemma : lemma.getRelationLemmas()) {
                    if (relationLemma.getProperty().equals(EntityEnum.BODY.toString())) {
                        BodyPart bodyPart = new BodyPart();
                        bodyPart.setName(relationLemma.getText());
                        bodyPart.setStandName(relationLemma.getText());
                        bodyPartList.add(bodyPart);
                    }
                }
                bodyMap.put(lemma.getText(), bodyPartList);
            }
        }

        //辅助检查
        List<Lemma> pacsAll = createEntityTree(aiOut, EntityEnum.AUXILIARY_EXAMINATION.toString());
        List<Pacs> disList = new ArrayList<>();
        for (Lemma lemma : pacsAll) {
            if (lemma.isHaveChildren()) {
                for (Lemma relationLemma : lemma.getRelationLemmas()) {
                    if (relationLemma.getProperty().equals(EntityEnum.DIEASE.toString())) {
                        // 辅检诊断信息
                        Pacs dis = new Pacs();
                        dis.setName(relationLemma.getText());
                        dis.setStandName(relationLemma.getText());
                        disList.add(dis);
                    }
                }
            }
        }
        //所有项目
        List<Item> collect = Lists.newArrayList();
        if(ListUtil.isNotEmpty(pacsAll)){
                collect = pacsAll.stream().map(x -> {
                Item item = new Item();
                item.setName(x.getText());
                item.setUniqueName(x.getText());
                return item;
            }).collect(Collectors.toList());
        }
        //描述和部位的关系
        List<Pacs> pacsResults = Lists.newArrayList();
        if(bodyMap != null && bodyMap.size() > 0){
            bodyMap.forEach((x,y) -> {
                Pacs pacs = new Pacs();
                pacs.setName(x);
                pacs.setStandName(x);
                pacs.setBodyPartList(y);
                pacsResults.add(pacs);
            });
        }

        pacsLabel.setDisease(disList);
        pacsLabel.setItem(collect);
        pacsLabel.setPacsResults(pacsResults);

    }

}
